#include "stm32f10x.h"
#include "antilib_gpio.h"

#define LED_BLUE_GPIO	GPIOC
#define LED_BLUE_PIN	8

void TIM3_IRQHandler(void)
{
	if(TIM3->SR & TIM_SR_UIF) // if UIF flag is set
	{
		TIM3->SR &= ~TIM_SR_UIF; // clear UIF flag
		LED_BLUE_GPIO->ODR ^= (1 << LED_BLUE_PIN); // toggle LED state
	}
}

int main(void)
{
	RCC->APB2ENR |= RCC_APB2ENR_IOPAEN | RCC_APB2ENR_IOPCEN;
	RCC->APB1ENR |= RCC_APB1ENR_TIM3EN;

	#if (LED_BLUE_PIN > 7)
	  LED_BLUE_GPIO->CRH = (LED_BLUE_GPIO->CRH & CONFMASKH(LED_BLUE_PIN)) | GPIOPINCONFH(LED_BLUE_PIN,     GPIOCONF(GPIO_MODE_OUTPUT2MHz, GPIO_CNF_OUTPUT_PUSHPULL));
	#else
	  LED_BLUE_GPIO->CRL = (LED_BLUE_GPIO->CRL & CONFMASKL(LED_BLUE_PIN)) | GPIOPINCONFL(LED_BLUE_PIN,     GPIOCONF(GPIO_MODE_OUTPUT2MHz, GPIO_CNF_OUTPUT_PUSHPULL));
	#endif

	TIM3->PSC = 23999;	         // Set prescaler to 24 000 (PSC + 1)
	TIM3->ARR = 1000;	           // Auto reload value 1000
	TIM3->DIER = TIM_DIER_UIE; // Enable update interrupt (timer level)
	TIM3->CR1 = TIM_CR1_CEN;   // Enable timer

	NVIC_EnableIRQ(TIM3_IRQn); // Enable interrupt from TIM3 (NVIC level)

	while(1);
}
